@@ -2,6 +2,8 @@ pref("extensions.{73a6fe31-595d-460b-a920-fcc0f8843232}.description", "chrome://
 pref("noscript.autoReload", true);
 pref("noscript.autoReload.global", true);
 pref("noscript.autoReload.allTabs", true);
+pref("noscript.autoReload.allTabsOnPageAction", true);
+pref("noscript.autoReload.allTabsOnGlobal", false);
 pref("noscript.autoReload.useHistory", false);
 pref("noscript.autoReload.useHistory.exceptCurrent", true);
 pref("noscript.ctxMenu", true);
@@ -18,22 +20,27 @@ pref("noscript.showDistrust", true);
 pref("noscript.showUntrusted", true);
 pref("noscript.showBaseDomain", true);
 pref("noscript.showGlobal", true);
+pref("noscript.showTempToPerm", true);
+pref("noscript.showRevokeTemp", true);
+pref("noscript.showBlockedObjects", true);
+pref("noscript.showTempAllowPage", true);
+pref("noscript.showAllowPage", true);
 pref("noscript.mandatory", "chrome: about: resource:");
-pref("noscript.default", "chrome: resource: about:blank about:neterror about:config about:plugins about:credits addons.mozilla.org flashgot.net google.com googlesyndication.com informaction.com yahoo.com yimg.com maone.net noscript.net hotmail.com msn.com passport.com passport.net passportimages.com live.com");
+pref("noscript.default", "chrome: resource: about:blank about:neterror about:config about:plugins about:credits addons.mozilla.org flashgot.net google.com googlesyndication.com informaction.com yahoo.com yimg.com maone.net noscript.net hotmail.com msn.com passport.com passport.net passportimages.com live.com recaptcha.net");
 pref("noscript.forbidJava", true);
 pref("noscript.forbidFlash", true);
 pref("noscript.forbidSilverlight", true);
 pref("noscript.forbidPlugins", true);
 pref("noscript.forbidActiveContentParentTrustCheck", true);
 pref("noscript.forbidIFrames", false);
-pref("noscript.forbidIFramesContext", 1);
+pref("noscript.forbidIFramesContext", 3);
 pref("noscript.forbidIFramesParentTrustCheck", true);
 
-pref("noscript.forbidData", false);
+pref("noscript.forbidData", true);
 pref("noscript.sound.block", "chrome://noscript/skin/block.wav");
 pref("noscript.allowClipboard", false);
 pref("noscript.allowLocalLinks", false);
-pref("noscript.pluginPlaceholder", "chrome://noscript/skin/icon32.png");
+
 pref("noscript.showPlaceholder", true);
 pref("noscript.global", false);
 pref("noscript.confirmUnblock", true);
@@ -56,6 +63,7 @@ pref("noscript.nselNever", false);
 pref("noscript.nselNoMeta", true);
 pref("noscript.autoAllow", 0);
 pref("noscript.toolbarToggle", 3);
+pref("noscript.allowPageLevel", 0);
 pref("noscript.forbidImpliesUntrust", false);
 pref("noscript.keys.toggle", "ctrl shift VK_BACK_SLASH.|");
 pref("noscript.keys.ui", "ctrl shift S");
@@ -74,7 +82,7 @@ pref("noscript.xss.notify.subframes", true);
 
 pref("noscript.xss.trustReloads", false);
 pref("noscript.xss.trustData", true);
-pref("noscript.xss.trustExternal", false);
+pref("noscript.xss.trustExternal", true);
 pref("noscript.xss.trustTemp", true);
 
 pref("noscript.filterXPost", true);
@@ -83,14 +91,11 @@ pref("noscript.filterXGetRx", "(?:<+(?=[^<>=\\d\\. ])|[\\\\\"\\x00-\\x07\\x09\\x
 pref("noscript.filterXGetUserRx", "");
 pref("noscript.filterXExceptions", "^http://([a-z]+)\\.google\\.(?:[a-z]{1,3}\\.)?[a-z]+/(?:search|custom|\\1)\\?\n^http://([a-z]*)\\.?search\\.yahoo\\.com/search(?:\\?|/\\1\\b)\n^http://[a-z]+\\.wikipedia\\.org/wiki/[^\"<>\?%]+$"); 
 pref("noscript.injectionCheck", 2);
-pref("noscript.injectionCheck.timeout", 800);
-pref("noscript.injectionCheck.loops", 20);
+pref("noscript.injectionCheckPost", true);
 
 pref("noscript.blockXIntranet", true);
 pref("noscript.intranetMaskRx", "^(127\\.[\\d.]+)");
 
-pref("noscript.blockCssScanners", true);
-
 pref("noscript.globalwarning", true);
 
 pref("noscript.jsredirectIgnore", false);
@@ -110,6 +115,7 @@ pref("noscript.fixURI.exclude", "");
 pref("noscript.blockNSWB", false);
 
 pref("noscript.urivalid.aim", "\\w[^\\\\\?&\\x00-\\x1f#]*(?:\\?[^\\\\\\x00-\\x1f#]*(?:#[\\w\\-\\.\\+@]{2,32})?)?");
+pref("noscript.urivalid.mailto", "[^\\x00-\\x08\\x0b\\x0c\\x0e-\\x1f]*");
 
 pref("noscript.forbidExtProtSubdocs", true);
 
@@ -120,6 +126,7 @@ pref("noscript.forbidJarDocumentsExceptions", "^jar:https://samples\\.noscript\\
 pref("noscript.jarDoc.notify", true);
 
 pref("noscript.forbidXBL", 4);
+pref("noscript.forbidXHR", 1);
 
 pref("noscript.whitelistRegExp", "");
 
@@ -129,6 +136,8 @@ pref("noscript.lockPrivilegedUI", false);
 
 
 pref("noscript.collapseObject", false);
+pref("noscript.opacizeObject", 1);
+
 pref("noscript.showUntrustedPlaceholder", true);
 
 pref("noscript.jsHack", "window.urchinTracker = function() {}");
@@ -137,3 +146,36 @@ pref("noscript.canonicalFQDN", true);
 
 pref("noscript.allowedMimeRegExp", "");
 pref("noscript.alwaysBlockUntrustedContent", true); 
+
+pref("noscript.consoleLog", false);
+
+pref("noscript.silverlightPatch", true);
+
+pref("noscript.allowURLBarJS", true);
+
+pref("noscript.docShellJSBlocking", 1);
+
+pref("noscript.hideOnUnloadRegExp", "video/.*");
+
+pref("noscript.untrustedGranularity", 3);
+pref("noscript.requireReloadRegExp", "application/x-vnd\\.moveplayer\\b.*");
+
+pref("noscript.trustEV", false);
+
+pref("noscript.secureCookies", false);
+pref("noscript.secureCookiesExceptions", "");
+pref("noscript.secureCookiesForced", "");
+pref("noscript.secureCookies.recycle", false);
+pref("noscript.secureCookies.perTab", false);
+
+pref("noscript.httpsForced", "");
+pref("noscript.allowHttpsOnly", 0);
+
+pref("noscript.https.showInConsole", true);
+
+pref("noscript.clearClick", 1);
+pref("noscript.clearClick.plugins", true);
+pref("noscript.clearClick.prompt", true);
+pref("noscript.clearClick.debug", false);
+
+pref("noscript.emulateFrameBreak", true);
