@@ -1,7 +1,7 @@
 const APP_DISPLAY_NAME = "NoScript";
 const APP_NAME = "noscript";
 const APP_PACKAGE = "/informaction/noscript";
-const APP_VERSION = "1.3.2";
+const APP_VERSION = "1.8.2.1";
 
 const APP_PREFS_FILE="defaults/preferences/noscript.js";
 const APP_XPCOM_SERVICE="components/noscriptService.js";
@@ -12,13 +12,15 @@ const APP_LOCALES = [
   "fi-FI","fr-FR","it-IT","nl-NL","tr-TR","zh-CN","ru-RU","bg-BG","ro-RO",
   "uk-UA", "th-TH", "fa-IR", "el-GR", "hr-HR", "he-IL", "be-BY", "vi-VN",
   "sk-SK", "hu-HU", "mk-MK", "da-DK", "sv-SE", "lt-LT", "zh-TW", // "sr-YU",
-  "id-ID", "es-AR", "ar", "de-AT", "ko-KR",
+  "id-ID", "es-AR", "ar", "de-AT", "ko-KR", "et-EE", // "sl-SI",
   "en-US"
   ];
 
-const APP_SUCCESS_MESSAGE = APP_DISPLAY_NAME+" should now be available when you restart the browser.";
+const APP_SUCCESS_MESSAGE = APP_DISPLAY_NAME + " should now be available when you restart the browser.";
 
-const INST_TO_PROFILE = "Do you wish to install "+APP_DISPLAY_NAME+" to your profile?\nIf you are in doubt, this is the preferred option: click OK.\n(Click Cancel if you want "+APP_DISPLAY_NAME+" installing to the Mozilla directory.)";
+const INST_TO_PROFILE = "Do you wish to install " + APP_DISPLAY_NAME + 
+  " to your profile?\nIf you are in doubt, this is the preferred option: click OK.\n(Click Cancel if you want " + 
+  APP_DISPLAY_NAME + " installing to the Mozilla directory.)";
 
 var instToProfile = true;
 
@@ -26,14 +28,27 @@ myPerformInstall(false);
 
 function myPerformInstall(secondTry) {
   
+  
+  
   var err;
   initInstall(APP_NAME, APP_PACKAGE, APP_VERSION);
   
-  if(!secondTry) {  
-    // profile installs only work since 2003-03-06
-    instToProfile = (buildID > 2003030600 && confirm(INST_TO_PROFILE));
+  function chromeExistsIn(folder) {
+    var chrome = getFolder(folder, APP_JAR_FILE);
+    var isDir = File.isDirectory(chrome);
+    if (!isDir) isDir = /\/$/.test(chrome);
+    if (isDir)
+      File.dirRemove(chrome);  
+    return !chrome || !isDir;
   }
   
+  if(!secondTry) {  
+    // profile installs only work since 2003-03-06
+    instToProfile = chromeExistsIn(getFolder("Profile", "chrome")) ||
+      !chromeExistsIn(getFolder("chrome")) && 
+        buildID > 2003030600 && !!confirm(INST_TO_PROFILE);
+  }
+
   var chromef = instToProfile ? getFolder("Profile", "chrome") : getFolder("chrome");
   err = addFile(APP_PACKAGE, APP_VERSION, "chrome/" + APP_JAR_FILE, chromef, null);
   
@@ -42,8 +57,8 @@ function myPerformInstall(secondTry) {
       getFolder(getFolder("Profile"),"pref"),
       getFolder(getFolder(getFolder("Program"),"defaults"),"pref")
       ];
-    for(var j=prefDirs.length; j-->0;) {
-      var prefDir=prefDirs[j];
+    for(var j = prefDirs.length; j-->0;) {
+      var prefDir = prefDirs[j];
       if(!File.exists(prefDir)) {
         File.dirCreate(prefDir);
       }
@@ -54,7 +69,7 @@ function myPerformInstall(secondTry) {
   
   if(err == SUCCESS) {
     var jar = getFolder(chromef, APP_JAR_FILE);
-    const chromeFlag=instToProfile?PROFILE_CHROME:DELAYED_CHROME;
+    const chromeFlag = instToProfile ? PROFILE_CHROME : DELAYED_CHROME;
   
     registerChrome(CONTENT | chromeFlag, jar, APP_CONTENT_FOLDER);
     var localesCount=APP_LOCALES.length;
@@ -87,7 +102,9 @@ function myPerformInstall(secondTry) {
               "You will need either to reinstall " + APP_DISPLAY_NAME + " once as Administrator / root or install SeaMonkey in an user-writable location.");
         err = xpcomError;
       } else {
-        alert(APP_DISPLAY_NAME+" "+APP_VERSION+" has been succesfully installed.\n"+APP_SUCCESS_MESSAGE);
+        alert(APP_DISPLAY_NAME+" "+APP_VERSION+" has been succesfully installed in your " + 
+          (instToProfile ? "profile" : "browser") +
+          ".\n" + APP_SUCCESS_MESSAGE);
       }
     } else {
       var msg = "Install failed!!! Error code:" + err;
