@@ -52,6 +52,7 @@ var nsopt = {
     this.trustedSites = ns.jsPolicySites.clone();
     this.untrustedSites = ns.untrustedSites.clone();
     this.tempSites = ns.tempSites.clone();
+    this.gTempSites = ns.gTempSites.clone();
     this.populateUrlList();
     
     this.jsglobal.checked = ns.jsEnabled;
@@ -67,6 +68,10 @@ var nsopt = {
       }
     );
     
+    this.utils.visitTextboxes(function(prefName, box) {
+      box.value = ns.getPref(prefName);  
+    });
+    
     document.getElementById("opt-showPermanent").setAttribute("label", noscriptUtil.getString("allowLocal", ["[...]"]));
     document.getElementById("opt-showTemp").setAttribute("label", noscriptUtil.getString("allowTemp", ["[...]"]));
     document.getElementById("opt-showDistrust").setAttribute("label", noscriptUtil.getString("distrust", ["[...]"]));
@@ -82,6 +87,9 @@ var nsopt = {
     this.autoAllowGroup = new ConditionalGroup(ns, "autoAllow", 0);
     this.toggleGroup = new ConditionalGroup(ns, "toolbarToggle", 3);
     
+    var val = ns.getPref("allowHttpsOnly", 0);
+    document.getElementById("sel-allowHttpsOnly").selectedIndex = (val < 0 || val > 2) ? 0 : val;
+    
     var shortcut = ns.getPref("keys.toggle");
     if(shortcut) {
       shortcut = shortcut.replace(/VK_([^\.]*).*/g, "$1").replace(/\s+/g, '+').replace(/_/g, ' ');
@@ -105,6 +113,15 @@ var nsopt = {
       document.getElementById("fx-notifications").setAttribute("hidden", "true");
     }
     
+    ["clearClick", "opacizeObject"].forEach(function(c) {
+      var pref = ns.getPref(c);
+      Array.forEach(document.getElementById(c + "Opts").getElementsByTagName("checkbox"), function(cbx) {        
+        cbx.setAttribute("checked", !(pref & parseInt(cbx.getAttribute("value"))) ? "false" : "true");
+
+      });
+    });
+    
+    
     // document.getElementById("policy-tree").view = policyModel;
     window.sizeToContent();
     
@@ -154,6 +171,19 @@ var nsopt = {
       }
     );
     
+    this.utils.visitTextboxes(function(prefName, box) {
+      ns.setPref(prefName, box.value);
+    });
+    
+    ["clearClick", "opacizeObject"].forEach(function(c) {
+      var pref = 0;
+      Array.forEach(document.getElementById(c + "Opts").getElementsByTagName("checkbox"), function(cbx) {
+        if (cbx.checked) pref = pref | parseInt(cbx.getAttribute("value"));
+      });
+      ns.setPref(c, pref);
+    });
+    
+    
     ns.setPref("notify.hideDelay", parseInt(document.getElementById("notifyDelay").value) || 
               ns.getPref("notify.hideDelay", 5));
 
@@ -162,6 +192,8 @@ var nsopt = {
     this.autoAllowGroup.persist();
     this.toggleGroup.persist();
     
+    ns.setPref("allowHttpsOnly", document.getElementById("sel-allowHttpsOnly").selectedIndex);
+    
     var exVal = this.xssEx.getValue();
     if(this.xssEx.validate() || !/\S/.test(exVal)) 
       ns.setPref("filterXExceptions", exVal);
@@ -177,14 +209,17 @@ var nsopt = {
     var untrustedSites = this.untrustedSites;
     var trustedSites = this.trustedSites;
     var tempSites = this.tempSites;
+    var gTempSites = this.gTempSites;
     
     ns.safeCapsOp(function() {
       if(ns.untrustedSites.sitesString != untrustedSites.sitesString
           || ns.jsPolicySites.sitesString != trustedSites.sitesString
-          || ns.tempSites.sitesString != tempSites.sitesString) {
+          || ns.tempSites.sitesString != tempSites.sitesString
+          || ns.gTempSites.sitesString != gTempSites.sitesString) {
         ns.untrustedSites.sitesString = untrustedSites.sitesString;
         ns.persistUntrusted();
         ns.setPref("temp", tempSites.sitesString);
+        ns.setPref("gtemp", gTempSites.sitesString);
         ns.setJSEnabled(trustedSites.sitesList, true, true);
       }
       ns.jsEnabled = global;
@@ -203,7 +238,7 @@ var nsopt = {
     this.removeButton.setAttribute("disabled", removeDisabled);
     document.getElementById("revokeButton")
       .setAttribute("disabled", this.tempRevoked || 
-          !(this.tempSites.sitesString || this.serv.objectWhitelistLen));
+          !(this.tempSites.sitesString || this.gTempSites.sitesString || this.serv.objectWhitelistLen));
     this.urlChanged();
   },
   
@@ -250,6 +285,8 @@ var nsopt = {
     const dom2 = this.dom2;
     var site, item;
     var match, k, len;
+    var tempSites = this.gTempSites.clone();
+    tempSites.add(this.tempSites.sitesList);
     var tempMap = this.tempSites.sitesMap;
     for(j = 0, len = sites.length; j < len; j++) {
       site = sites[j];
@@ -270,7 +307,9 @@ var nsopt = {
     const site = this.serv.getSite(this.urlText.value);
     this.trustedSites.add(site);
     this.tempSites.remove(site, true, true); // see noscriptService#eraseTemp()
-    this.untrustedSites.remove(site);
+    this.gTempSites.remove(site, true, true);
+    
+    this.untrustedSites.remove(site, false, !this.serv.mustCascadeTrust(site, false));
     this.populateUrlList();
     this.ensureVisible(site);
     this.addButton.setAttribute("disabled", "true");
@@ -314,9 +353,12 @@ var nsopt = {
   tempRevoked: false,
   revokeTemp: function() {
     const ns = this.serv;
-    this.trustedSites.remove(this.tempSites.sitesList, true, true); 
+    this.trustedSites.remove(this.tempSites.sitesList, true, true);
+    this.trustedSites.remove(this.gTempSites.sitesList, true, true);
+    this.untrustedSites.add(this.gTempSites.sitesList);
     this.trustedSites.add(ns.permanentSites.sitesList);
     this.tempSites.sitesString = "";
+    this.gTempSites.sitesString = "";
     this.tempRevoked = true;
     this.populateUrlList();
   },
@@ -358,15 +400,15 @@ var nsopt = {
   },
   
   importList: function(file) {
-    var all = this.serv.readFile(file);
-    var untrustedPos = all.indexOf("\n[UNTRUSTED]\n");
+    var all = this.serv.readFile(file).replace(/\s+/g, "\n");
+    var untrustedPos = all.indexOf("[UNTRUSTED]");
     if(untrustedPos < 0) {
       this.trustedSites.sitesString += "\n" + all;
     } else {
       this.trustedSites.sitesString += "\n" + all.substring(0, untrustedPos);
       this.untrustedSites.sitesString += all.substring(all.indexOf("\n", untrustedPos + 2));
     }
-    this.untrustedSites.remove(this.trustedSites.sitesList);
+    this.untrustedSites.remove(this.trustedSites.sitesList, false, true);
     this.populateUrlList();
     return null;
   },
@@ -393,6 +435,9 @@ var nsopt = {
   buttonToTitle: function(btid) {
     return "NoScript - " + document.getElementById(btid).getAttribute("label");
   }
+  
+  
+  
 }
 
 /*
