@@ -31,14 +31,15 @@ var noscriptOverlay = noscriptUtil.service ?
     return noscriptUtil.getString(key, parms);
   }
 ,
-  toggleCurrentPage: function(force) {
+  toggleCurrentPage: function(forceLevel) {
     const ns = this.ns;
-    var level = ns.getPref("toolbarToggle", 3) || force;
+    var level = ns.getPref("toolbarToggle", 3) || forceLevel;
     if (!level) return false;
     
     const url = ns.getQuickSite(content.document.documentURI, level);
+    if (url)
+      this.safeAllow(url, !ns.isJSEnabled(url), ns.getPref("toggle.temp"));
     
-    this.safeAllow(url, !ns.isJSEnabled(url), ns.getPref("toggle.temp"));
     return true;
   },
 
@@ -48,7 +49,8 @@ var noscriptOverlay = noscriptUtil.service ?
   },
   
   get prompter() {
-    return noscriptUtil.prompter;
+    delete this.prompter;
+    return this.prompter = noscriptUtil.prompter;
   },
   
   onMenuShowing: function(ev) {
@@ -118,12 +120,22 @@ var noscriptOverlay = noscriptUtil.service ?
     return popup;
   },
   
+  tempSitesForTooltip: function(tempSites) {
+    // remove http/https/file CAPS hack entries
+    if (!tempSites) return "0 | ";
+    tempSites = this.ns.siteUtils.sanitizeString(tempSites.replace(/\b(?:https?|file):\/\//g, "")).split(/\s+/);
+    return (typeof(/ /) == "object") // Fx 3, multiline tooltips
+        ? tempSites.join(", ") + "\n\n"
+        : tempSites.length + " | ";
+  },
+  
   prepareMenu: function(popup) {
     const ns = this.ns;
 
     var j, k, node;
     
     const global = ns.jsEnabled;
+    const blockUntrusted = global && ns.alwaysBlockUntrustedContent;
     
     var allSeps = popup.getElementsByTagName("menuseparator");
    
@@ -155,30 +167,32 @@ var noscriptOverlay = noscriptUtil.service ?
     
     node = miGlobal.nextSibling;
     const mainMenu = node.parentNode;
-
-    if (!/\bnoscript-revoke-temp\b/.test(node.className)) {
-      node = mainMenu.insertBefore(document.getElementById("noscript-revoke-temp-mi").cloneNode(true), node);
-      node.id = "";
+    
+    var tempMenuItem = document.getElementById("noscript-revoke-temp-mi");
+    if (node != tempMenuItem) {
+      node = mainMenu.insertBefore(tempMenuItem, node);
     }
-    if ((ns.tempSites.sitesString || ns.objectWhitelistLen) && ns.getPref("showRevokeTemp", true)) {
+    
+    var tempSites = ns.gTempSites.sitesString;
+    tempSites = tempSites && (tempSites + " " + ns.tempSites.sitesString).replace(/\s+$/g, '') || ns.tempSites.sitesString;
+    if ((tempSites || ns.objectWhitelistLen) && ns.getPref("showRevokeTemp", true)) {
       node.hidden = seps.global.hidden = false;
       node.setAttribute("tooltiptext",
-        // remove http/https/file CAPS hack entries 
-        "<SCRIPT>: " + 
-        (ns.tempSites.sitesString 
-          ? ns.siteUtils.sanitizeString(ns.tempSites.sitesString.replace(/\b(?:https?|file):\/\//g, ""
-              )).split(/\s+/) 
-              // .join(",\n") // wait Firefox 3 with its multiline tooltips for this
-              .length
-          : 0) +
-        " | <OBJECT>: " + ns.objectWhitelistLen
-      );
+        "<SCRIPT>: " + (this.tempSitesForTooltip(tempSites)) +
+        "<OBJECT>: " + ns.objectWhitelistLen
+        );
     } else {
       node.hidden = true;
     }
     node = node.nextSibling;
-   
-
+    
+    tempMenuItem = document.getElementById("noscript-temp-allow-page-mi");
+    if (node != tempMenuItem) {
+      mainMenu.insertBefore(tempMenuItem, node)
+    } else {
+      node = node.nextSibling;
+    }
+    
     var xssMenu = document.getElementById("noscript-xss-menu");
     
     if (xssMenu && node != xssMenu) {
@@ -225,6 +239,13 @@ var noscriptOverlay = noscriptUtil.service ?
     mainMenu.appendCmd = function(n) { this.insertBefore(n, seps.stop); };
 
     const sites = this.getSites();
+    j = sites.indexOf(sites.topURL);
+    if (j > 0) {
+      sites.splice(j, 1);
+      sites.push(sites.topURL);
+    }
+    
+    
     try {
       this.populatePluginsMenu(mainMenu, pluginsMenu, sites.pluginExtras);
     } catch(e) {
@@ -233,7 +254,7 @@ var noscriptOverlay = noscriptUtil.service ?
     var site, enabled, isTop, lev;
     var jsPSs = ns.jsPolicySites;
     var matchingSite;
-    var menuSites, menuSite, scount;
+    var menuGroups, menuSites, menuSite, scount;
     var domain, pos, baseLen, dp;
     var untrusted;
     var cssClass;
@@ -246,32 +267,45 @@ var noscriptOverlay = noscriptUtil.service ?
     };
     
     const locked = ns.locked;
-    const showAddress = locked || ns.getPref("showAddress", false);
-    const showDomain = !locked && ns.getPref("showDomain", false);
-    const showBase = !locked && ns.getPref("showBaseDomain", true);
+    const addressOnly = locked;
+    const showAddress = addressOnly || ns.getPref("showAddress", false);;
+    const showDomain = !addressOnly && ns.getPref("showDomain", false);
+    const showBase = !addressOnly && ns.getPref("showBaseDomain", true);
     const showUntrusted = ns.getPref("showUntrusted", true);
     const showDistrust = ns.getPref("showDistrust", true);
     const showNothing = !(showAddress || showDomain || showBase || showUntrust);
-    
+    // const forbidImpliesUntrust = ns.forbidImpliesUntrust;
     
     const showPermanent = ns.getPref("showPermanent", true);
     const showTemp = !locked && ns.getPref("showTemp", true);
     
     var parent, extraNode;
-    var untrustedCount = 0;
+    var untrustedCount = 0, unknownCount = 0, tempCount = 0;
+    const untrustedSites = ns.untrustedSites;
+    var docJSBlocked = false;
     
-    for (j = sites.length; j-->0;) {
+    menuGroups = [];
+    for (j = sites.length; j-- > 0;) {
       site = sites[j];
       
       matchingSite = jsPSs.matches(site);
-      enabled = !!matchingSite;
-      isTop = site == sites.topURL;
+      untrusted = untrustedSites.matches(site);
+      if (untrusted) {
+        matchingSite = null;
+      } else if (blockUntrusted && !matchingSite) {
+        matchingSite = site;
+      }
       
-      if (enabled) {
+      isTop = site == sites.topURL;
+      enabled = !!matchingSite;
+      docJSBlocked = enabled && isTop && !gBrowser.selectedBrowser.webNavigation.allowJavascript;
+      if (docJSBlocked) enabled = false;
+      
+      if (enabled && !global || (matchingSite = untrusted)) {
         if (domainDupChecker.check(matchingSite)) continue;
         menuSites = [matchingSite];
       } else {
-        domain = ns.getDomain(site);
+        domain = !ns.isForbiddenByHttpsStatus(site) && ns.getDomain(site);
         
         if (domain && (dp = ns.getPublicSuffix(domain)) == domain) 
           domain = null; // exclude TLDs
@@ -284,7 +318,7 @@ var noscriptOverlay = noscriptUtil.service ?
           if (baseLen == domain.length) {
             // IP or 2nd level domain
             if (!domainDupChecker.check(domain)) {
-              menuSites[menuSites.length] = domain;
+              menuSites.push(domain);
             }
           } else {
             dp = domain;
@@ -295,77 +329,130 @@ var noscriptOverlay = noscriptUtil.service ?
                 if (!showDomain) continue;
               }
               if (!domainDupChecker.check(dp)) {
-                menuSites[menuSites.length] = dp;
+                menuSites.push(dp);
               }
               if (baseLen == dp.length) break;
             }
           }
-        }
+        }  
       }
-      
+      menuSites.isTop = isTop;
+      menuSites.enabled = enabled;
+      menuGroups.push(menuSites);
+    }
+    
+    var blurred;
+    
+    for (j = menuGroups.length; j-- > 0;) {
+
       if (seps.stop.previousSibling.nodeName != "menuseparator") {
         mainMenu.appendCmd(document.createElement("menuseparator"));
       }
       
- 
-   
+      menuSites = menuGroups[j];
+      isTop = menuSites.isTop;
+      enabled = menuSites.enabled;
+      
       for (scount = menuSites.length; scount-- > 0;) {
         menuSite = menuSites[scount];
         
-        if (untrusted = (!enabled) && ns.isUntrusted(menuSite)) 
+        untrusted = !enabled && (blockUntrusted || ns.isUntrusted(menuSite));
+        if (untrusted) 
           untrustedCount++;
+        else if (!enabled)
+          unknownCount++;
         
         parent = (untrusted && showUntrusted) ? untrustedMenu : mainMenu;
         if (!parent) continue;
         
         node = document.createElement("menuitem");
         cssClass = isTop ? "noscript-toplevel noscript-cmd" : "noscript-cmd";
-        node.setAttribute("label", this.getString((enabled ? "forbidLocal" : "allowLocal"), [menuSite]));
+        
+        domain = isTop && docJSBlocked ? "[ " + menuSite + " ]" : menuSite;
+        
+        node.setAttribute("label", this.getString((enabled ? "forbidLocal" : "allowLocal"), [domain]));
         node.setAttribute("statustext", menuSite);
         node.setAttribute("oncommand", "noscriptOverlay.menuAllow(" + (!enabled) + ", this)");
         node.setAttribute("tooltiptext",
           this.getString("allowed." + (enabled ? "yes" : "no")));
-        if (locked || enabled && ns.isPermanent(menuSite)) {
+        
+        blurred = false;
+        if (locked || (enabled ? ns.isPermanent(menuSite) : blurred = ns.isForbiddenByHttpsStatus(menuSite))) {
           node.setAttribute("disabled", "true");
         } else {
           cssClass += " menuitem-iconic ";
-          if (enabled && ns.isTemp(menuSite)) cssClass += " noscript-temp";
+          if (enabled && ns.isTemp(menuSite)) {
+            cssClass += " noscript-temp";
+            tempCount++;
+          }
         }
+        
         node.setAttribute("class", cssClass + (enabled ? " noscript-forbid" : " noscript-allow"));
         
-        if (showPermanent || enabled) 
+        if ((showPermanent || enabled) && !(global && enabled)) 
           parent.appendCmd(node);
         
-        if (!(enabled || locked)) {
-          if (showTemp) {
+        if (!locked) {
+          if (showTemp && !(enabled || blurred)) {
             extraNode = document.createElement("menuitem");
-            extraNode.setAttribute("label", this.getString("allowTemp", [menuSite]));
+            extraNode.setAttribute("label", this.getString("allowTemp", [domain]));
             extraNode.setAttribute("statustext", menuSite);
             extraNode.setAttribute("oncommand", "noscriptOverlay.menuAllow(true,this,true)");
             extraNode.setAttribute("class", cssClass + " noscript-temp noscript-allow");
             extraNode.setAttribute("tooltiptext", node.getAttribute("tooltiptext"));
             parent.appendCmd(extraNode);
           }
-          if (((showUntrusted && untrustedMenu) || showDistrust) && !untrusted) {
+          if (((showUntrusted && untrustedMenu || showDistrust) && !(domain in jsPSs.sitesMap) || blockUntrusted) && !untrusted) {
             extraNode = document.createElement("menuitem");
             extraNode.setAttribute("label", this.getString("distrust", [menuSite]));
             extraNode.setAttribute("statustext", menuSite);
             extraNode.setAttribute("class", cssClass + " noscript-distrust");
             extraNode.setAttribute("oncommand", "noscriptOverlay.menuAllow(false, this, false)");
             extraNode.setAttribute("tooltiptext", node.getAttribute("tooltiptext"));
-            (showUntrusted ? untrustedMenu : mainMenu).appendCmd(extraNode);
+            (showUntrusted && !blockUntrusted ? untrustedMenu : mainMenu).appendCmd(extraNode);
           }
         }
       }
       
+      if (untrustedMenu && untrustedMenu.firstChild) {
+        untrustedMenu.appendCmd(document.createElement("menuseparator"));
+      }
     }
     if (untrustedMenu && untrustedMenu.firstChild) {
-      untrustedMenu.appendCmd(document.createElement("menuseparator"));
       if (untrustedCount) 
         with(untrustedMenu.parentNode)
           setAttribute("label", getAttribute("label") +
             " (" + untrustedCount + ")"); // see above for cleanup
     }
+
+    
+    
+    // temp allow all this page
+    if (!(tempMenuItem.hidden = !(unknownCount && ns.getPref("showTempAllowPage", true)))) {
+      tempMenuItem.setAttribute("tooltiptext", this.allowPage(false, true).join(", "));
+    }
+
+    
+    // allow all this page
+    node = document.getElementById("noscript-allow-page-mi");
+    if (node.nextSibling != tempMenuItem) {
+      tempMenuItem.parentNode.insertBefore(node, tempMenuItem);
+    }
+    if (!(node.hidden = unknownCount == 0 || !ns.getPref("showAllowPage", true))) {
+      node.setAttribute("tooltiptext", this.allowPage(true, true).join(", "));
+    }
+    
+    // make permanent
+    node = document.getElementById("noscript-temp2perm-mi");
+    if (tempMenuItem.nextSibling != node) {
+      tempMenuItem.parentNode.insertBefore(node, tempMenuItem.nextSibling);
+    }
+    if (!(node.hidden = tempCount == 0 || !ns.getPref("showTempToPerm"))) {
+      node.setAttribute("tooltiptext", this.tempToPerm(true).join(", "));
+    }
+    
+    
+    
     this.normalizeMenu(untrustedMenu, true);
     this.normalizeMenu(mainMenu, false);
     
@@ -392,9 +479,10 @@ var noscriptOverlay = noscriptUtil.service ?
     var pluginExtras = [];
     i = 0;
     for each(egroup in extras) {
-      for each(e in egroup) {
+      for (i = egroup.length; i-- > 0;) {
+         e = egroup[i];
          
-         if(e.tag && !e.placeholder) continue;
+         if(typeof(e) == "object" && (e.tag && !e.placeholder)) continue;
          node = document.createElement("menuitem");
          
          e.label = e.label || ns.mimeEssentials(e.mime) + "@" + ns.urlEssentials(e.url);
@@ -406,10 +494,10 @@ var noscriptOverlay = noscriptUtil.service ?
          node.setAttribute("class", "menuitem-iconic noscript-cmd noscript-temp noscript-allow");
          node.style.listStyleImage = ns.cssMimeIcon(e.mime, 16);
          menu.appendChild(node);
-         pluginExtras[i++] = e;
+         pluginExtras.push(e);
       }
     }
-    if (i) {
+    if (pluginExtras.length) {
       noscriptOverlay.menuPluginExtras = pluginExtras;
       mainMenu.addEventListener("popuphidden", function(ev) {
           if (ev.currentTarget != ev.target) return;
@@ -454,6 +542,34 @@ var noscriptOverlay = noscriptUtil.service ?
     }
   },
   
+  allowPage: function(permanent, justTell) {
+    const ns = this.ns;
+    const sites = this.getSites();
+    const unknown = [];
+    const level = ns.getPref("allowPageLevel", 0) || ns.preferredSiteLevel;
+    var site;
+    for (var j = sites.length; j-- > 0;) {
+      site = ns.getQuickSite(sites[j], level);
+      
+      if (permanent === -1 // tempToPerm
+          ? ns.isTemp(site) && ns.isJSEnabled(site) 
+          : !(ns.isJSEnabled(site) || ns.isUntrusted(site)))
+        unknown.push(site);
+    }
+    if (!justTell) {
+      if (unknown.length) {
+        var browser = gBrowser.selectedBrowser;
+        ns.setExpando(browser, "allowPageURL", browser.docShell.currentURI.spec);
+        this.safeAllow(unknown, true, !permanent);
+      }
+    }
+    return unknown;
+  },
+  
+  tempToPerm: function(justTell) {
+    return this.allowPage(-1, justTell);
+  },
+  
   allowObject: function(i) {
     if(this.menuPluginExtras && this.menuPluginExtras[i]) {
       var e = this.menuPluginExtras[i];
@@ -464,6 +580,7 @@ var noscriptOverlay = noscriptUtil.service ?
       }
     }
   },
+  
   allowObjectSite: function(i) {
     if(this.menuPluginSites && this.menuPluginSites[i]) {
       this.allowObjectURL(this.menuPluginSites[i][0], this.menuPluginSites[i][1]);
@@ -506,10 +623,11 @@ var noscriptOverlay = noscriptUtil.service ?
   }
 ,
   revokeTemp: function() {
-    noscriptOverlay.ns.safeCapsOp(function() {
-      noscriptOverlay.ns.eraseTemp();
+    const ns = noscriptOverlay.ns;
+    ns.safeCapsOp(function() {
+      ns.eraseTemp();
       noscriptOverlay.syncUI();
-    });
+    }, !ns.getPref("autoReload.allTabsOnPageAction", true));
   }
 ,
   menuAllow: function(enabled, menuItem, temp) {
@@ -531,21 +649,41 @@ var noscriptOverlay = noscriptUtil.service ?
 ,
   safeAllow: function(site, enabled, temp) {
     const ns = this.ns;
+    var webNav = gBrowser.selectedBrowser.webNavigation;
+    var reloadCurrentTabOnly = (site instanceof Array) &&
+      !ns.getPref("autoReload.allTabsOnPageAction", true);
+
     ns.safeCapsOp(function() {
       if (site) {
+        
         ns.setTemp(site, enabled && temp);
-        ns.setJSEnabled(site, enabled);
+        ns.setJSEnabled(site, enabled, false, ns.mustCascadeTrust(site, temp));
+        
+        if (enabled && !webNav.allowJavascript) {
+          var curSite = ns.getSite(webNav.currentURI.spec);
+          if (ns.isJSEnabled(curSite)) {
+            // force reload
+            if (ns.jsEnabled) {
+              ns._lastSnapshot.add(curSite); 
+            } else {
+              ns._lastSnapshot.remove(curSite); 
+            }
+          }
+          webNav.allowJavascript = true;
+        }
       } else {
         ns.jsEnabled = enabled;
       }
       noscriptOverlay.syncUI();
-    });
+    }, reloadCurrentTabOnly);
   }
 ,
   
-  _statusIcon: null,
   get statusIcon() {
-    return this._statusIcon || document.getElementById("noscript-statusIcon");
+    var statusIcon = document.getElementById("noscript-statusIcon");
+    if (!statusIcon) return null; // avoid mess with early calls
+    delete this.statusIcon;
+    return this.statusIcon = statusIcon;
   },
 
   getIcon: function(node) {
@@ -559,8 +697,8 @@ var noscriptOverlay = noscriptUtil.service ?
     return "noscript-" + (inactive ? "inactive-" : "") + lev;
   },
   updateStatusClass: function(node, className) {
-    if (!className) className = this.statusIcon.className.replace(/.*(\bnoscript-\S*(?:yes|no|glb|prt|yu)).*/, "$1");
-    node.className = (node.className.replace(/\bnoscript-\S*(?:yes|no|glb|prt|yu)\b/g, "") + " " + className).replace(/\s{2,}/g, " ");
+    if (!className) className = this.statusIcon.className.replace(/.*(\bnoscript-\S*(?:yes|no|glb|prt|yu|untrusted)).*/, "$1");
+    node.className = (node.className.replace(/\bnoscript-\S*(?:yes|no|glb|prt|yu|untrusted)\b/g, "") + " " + className).replace(/\s{2,}/g, " ");
   }
 ,
   _syncTimeout: null,
@@ -1017,7 +1155,8 @@ var noscriptOverlay = noscriptUtil.service ?
     var allowedSites = [];
     var allowed = 0;
     var untrusted = 0;
-    if (global) {
+    var isUntrusted = false;
+    if (global && !ns.alwaysBlockUntrustedContent) {
       lev = "glb";
     } else {
       var s = sites.length;
@@ -1025,7 +1164,12 @@ var noscriptOverlay = noscriptUtil.service ?
       var url, site;
       while (s-- > 0) {
         url = sites[s];
-        site = jsPSs.matches(url);
+        isUntrusted = untrustedSites.matches(url);
+        site = !isUntrusted && (global ? url : jsPSs.matches(url));
+        
+        if (site && url == sites.topURL && !gBrowser.selectedBrowser.webNavigation.allowJavascript)
+          site = null;
+          
         if (site) {
           if (ns.isPermanent(site) || allowedSites.indexOf(site) > -1) {
             total--;
@@ -1034,18 +1178,21 @@ var noscriptOverlay = noscriptUtil.service ?
           }
         } else {
           if(!notificationNeeded && url != "about:blank") {
-            if(untrustedSites.matches(url)) untrusted++;
+            if(isUntrusted) untrusted++;
             else notificationNeeded = true;
           }
         }
       }
       allowed = allowedSites.length;
-      lev = (allowed == total && sites.length > 0) ? "yes" : allowed == 0 ? "no" 
-            : (untrusted > 0 && !notificationNeeded ? "yu" : "prt");
+      lev = (allowed == total && sites.length > 0 && !untrusted) ? (global ? "glb" : "yes")
+            : allowed == 0 ? (global ? "untrusted-glb" : "no") 
+            : (untrusted > 0 && !notificationNeeded ? (global ? "yu-glb" : "yu") : "prt");
       notificationNeeded = notificationNeeded && totalAnnoyances > 0;
     }
     
-    var message = this.getString("allowed." + (lev == "yu" ? "prt" : lev));
+    var message = this.getString("allowed." +
+        (lev == "yu" ? "prt" : lev == "untrusted" ? "no" : lev));
+    
     var shortMessage = message.replace(/JavaScript/g, "JS");
     
     if (notificationNeeded && allowed) 
@@ -1179,7 +1326,7 @@ var noscriptOverlay = noscriptUtil.service ?
     execute: function(cmd) {
       switch (cmd) {
         case 'toggle':
-          noscriptOverlay.toggleCurrentPage(3);
+          noscriptOverlay.toggleCurrentPage(noscriptOverlay.ns.preferredSiteLevel);
           break;
         case 'ui':
            noscriptOverlay.showUI();
@@ -1258,6 +1405,60 @@ var noscriptOverlay = noscriptUtil.service ?
     }
   },
   
+  hideObject: function(p, o) {
+    if (!p.mimeRx.test(o.type)) return;
+    
+    var r = p.document.createElement("object");
+    r.style.width = o.offsetWidth + "px";
+    r.style.height = o.offsetHeight + "px";
+    r.style.display = "inline-block";
+    o.className += " " + p.className;
+    o.parentNode.insertBefore(r, o);
+  },
+  
+  showObject: function(p, o) {
+    var cs = o.className;
+    cs = cs.replace(p.classRx, '');
+    if (cs != o.className) {
+      o.className = cs;
+      var r = o.previousSibling;
+      if (r instanceof HTMLObjectElement) {
+        r.parentNode.removeChild(r);
+      }
+    }
+  },
+  
+  _tags: ["object", "embed"],
+  toggleObjectsVisibility: function(d, v) {
+    var ns = noscriptOverlay.ns;
+    var rx = ns.hideOnUnloadRegExp;
+    if (!rx) return;
+    var callback = v ? noscriptOverlay.showObject : noscriptOverlay.hideObject;
+    var params = {
+      document: d,
+      mimeRx: rx,
+      classRx: noscriptOverlay.ns.hideObjClassNameRx,
+      className: ns.hideObjClassName
+    };
+    var aa = null;
+    var j;
+    for each(var t in this._tags) {
+      var oo = d.getElementsByTagName(t);
+      j = oo.length;
+      if (j) {
+        aa = aa || [oo[--j]];
+        while(j-- > 0) {
+          aa.push(oo[j]);
+        }
+      }
+    }
+    if (aa) {
+      for (j = aa.length; j-- > 0;) {
+        callback(params, aa[j]);
+      }
+    }
+  },
+  
   listeners: {
     
     onBrowserClick: function(ev) { 
@@ -1315,6 +1516,7 @@ var noscriptOverlay = noscriptUtil.service ?
               noscriptOverlay._syncUINow();
             }
           } else {
+            ns.frameContentLoaded(w);
             noscriptOverlay.syncUI(w.top);
           }
           w.addEventListener("load", noscriptOverlay.listeners.onDocumentLoad, false);
@@ -1329,9 +1531,18 @@ var noscriptOverlay = noscriptUtil.service ?
         }, 0);
       }
     },
+    
+    onPageShow: function(ev) {
+      if (ev.persisted && (ev.target instanceof HTMLDocument)) {
+        noscriptOverlay.toggleObjectsVisibility(ev.target, true);
+      }
+    },
     onPageHide: function(ev) {
-      ev.currentTarget.removeEventListener("pagehide", arguments.callee, true);
-      noscriptOverlay.cleanupDocument(ev.originalTarget);
+      var d = ev.target;
+      if (d instanceof HTMLDocument) {
+        noscriptOverlay.cleanupDocument(d);
+        noscriptOverlay.toggleObjectsVisibility(d, false);
+      }
     },
     
     onContextMenu:  function(ev) { noscriptOverlay.prepareContextMenu(ev) },
@@ -1342,7 +1553,9 @@ var noscriptOverlay = noscriptUtil.service ?
       try {
         noscriptOverlay.listeners.setup(); 
         noscriptOverlay.wrapBrowserAccess();
-        window.setTimeout(noscriptOverlay.pdfDownloadHack, 0);
+        var hacks = noscriptOverlay.Hacks;
+        hacks.torButton();
+        window.setTimeout(hacks.pdfDownload, 0);
       } catch(e) {
         var msg = "[NoScript] Error initializing new window " + e + "\n"; 
         noscriptOverlay.ns.log(msg);
@@ -1373,8 +1586,12 @@ var noscriptOverlay = noscriptUtil.service ?
       if (b.tabContainer) {
         b.tabContainer.addEventListener("TabClose", this.onTabClose, false);
       }
-
+      
       window.addEventListener("DOMContentLoaded", this.onContentLoad, false);
+      
+      
+      window.addEventListener("pageshow", this.onPageShow, true);
+      window.addEventListener("pagehide", this.onPageHide, true);
 
       noscriptOverlay.shortcutKeys.register();
       noscriptOverlay.prefsObserver.register();
@@ -1396,7 +1613,9 @@ var noscriptOverlay = noscriptUtil.service ?
         
         b.removeProgressListener(this.webProgressListener);
       }
-  
+      
+      window.removeEventListener("pagehide", this.onPageHide, true);
+      window.removeEventListener("pageshow", this.onPageShow, true);
       window.removeEventListener("DOMContentLoaded", this.onContentLoad, false);
 
       noscriptOverlay.prefsObserver.remove();
@@ -1426,6 +1645,10 @@ var noscriptOverlay = noscriptUtil.service ?
     }
   },
   
+  isBrowserEnabled: function(browser) {
+    browser = browser || gBrowser.selectedBrowser;
+    return browser.docShell.allowJavascript;
+  },
  
   
   wrapBrowserAccess: function() { // called onload
@@ -1482,7 +1705,7 @@ var noscriptOverlay = noscriptUtil.service ?
       var w = null;
       try {
         w = nsBrowserAccess.prototype.openURI.apply(this, arguments);
-        if (external) ns.dump("[NoScript] external load intercepted");
+        if (external && ns.consoleDump) ns.dump("[NoScript] external load intercepted");
       } finally {
         if (external && !w) ns.requestWatchdog.externalLoad = null;
       }
@@ -1490,11 +1713,25 @@ var noscriptOverlay = noscriptUtil.service ?
     }
   },
   
-  pdfDownloadHack: function() {
-    if (typeof(mouseClick) != "function") return;
-    var tb = getBrowser();
-    tb.removeEventListener("click", mouseClick, true);
-    tb.addEventListener("click", mouseClick, false);
+  Hacks: {
+  
+    pdfDownload: function() {
+      if (typeof(mouseClick) != "function") return;
+      var tb = getBrowser();
+      tb.removeEventListener("click", mouseClick, true);
+      tb.addEventListener("click", mouseClick, false);
+    },
+    
+    torButton: function() {
+      if (typeof(window.torbutton_update_tags) == "function") {
+        // we make TorButton aware that we could have a part in suppressing JavaScript on the browser
+        noscriptOverlay.ns.log("TB: " + window.torbutton_update_tags);
+        window.eval(
+          window.torbutton_update_tags.toSource().replace(/\bgetBoolPref\("javascript\.enabled"\)/g,
+          "$& && (!noscriptOverlay || noscriptOverlay.isBrowserEnabled(browser))"));
+        noscriptOverlay.ns.log("Patched TB: " + window.torbutton_update_tags);
+      }
+    }
   },
   
   install: function() {
